= Proceso de release =

1. Cambiar el número de versión en `setup.py`

2. Generar el paquete

```
python setup.py sdist bdist_wheel
```

3. Subirlo a pypi

```
twine upload dist/*
```

TODO: Configuración inicial de twine.
